@@ -310,3 +310,56 @@ def sort_dict_list_by_list(dict_list: List[dict], sort_value_list: List[str], na
     ordered_list = [name_to_dict[name] for name in sort_value_list if name in name_to_dict]
 
     return ordered_list
+
+
+def find_all_parents(tree, target_list, parent_key="parent_id", key="id", children_key="children", value_key="name"):
+    """
+    查找树形结构中每个目标元素的所有父级（包括间接父级）
+
+    参数:
+    target_list: 需要查找父级的目标值列表
+
+    返回:
+    字典，key为目标值，value为该目标的所有父级列表（从直接父级到根父级）
+    """
+    # 创建节点映射表：value -> node_info (包含parent_id和children)
+    node_map = {}
+
+    def build_map(nodes):
+        """递归构建节点映射表"""
+        for node in nodes:
+            node_map[node[key]] = {
+                parent_key: node.get(parent_key, ''),
+                value_key: node.get(value_key, ''),
+                children_key: node.get(children_key, [])
+            }
+            if children_key in node and node[children_key]:
+                build_map(node[children_key])
+
+    # 构建节点映射表
+    build_map(tree)
+
+    result = {}
+
+    def find_parents(value, parents_list):
+        """递归查找某个节点的所有父级"""
+        node_info = node_map.get(value)
+        if not node_info:
+            return parents_list
+
+        parent_id = node_info[parent_key]
+        if parent_id and parent_id in node_map:
+            parents_list.append(parent_id)
+            return find_parents(parent_id, parents_list)
+        return parents_list
+
+    # 为每个目标值查找所有父级
+    for target in target_list:
+        if target in node_map:
+            # 查找该节点的所有父级（从直接父级开始到根节点）
+            parents = find_parents(target, [])
+            result[target] = parents
+        else:
+            result[target] = []  # 如果节点不存在，返回空列表
+
+    return result
