@@ -2,7 +2,7 @@ class MyDict(dict):
 
     def get(self, key, default=None):
         value = super().get(key, default)
-        value = value if bool(value) else default
+        value = value if value is not None else default
         return self._process_value(value)
 
     def _process_value(self, value):
